/* gss.h --- Header file for GSSLib.                                  -*- c -*-
 * Copyright (C) 2003, 2004  Simon Josefsson
 *
 * This file is part of the Generic Security Service (GSS).
 *
 * GSS is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GSS is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSS; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _GSS_H
#define _GSS_H

#ifdef __cplusplus
extern "C" {
#endif

#define GSS_VERSION "0.0.9"

#include <gss/api.h>
#include <gss/ext.h>
#include <gss/krb5.h>

#ifdef __cplusplus
}
#endif

#endif /* _GSS_H */
